<h2 align="center">
:compass: Atlas Client :compass:
</h2>
<p align="center">
a python client for Atlas
</p>


### Development
To setup a dev environment, run:

```bash
make dev
```
This will set up a version of the python client for development.


### Testing
Run the unit tests.

```
make test
```

### Code Formatting
we use _black_ for code formatting. 

```
make code_format
```

### Documentation
```
make documentation
```